@@ -76,7 +76,10 @@ class AwsCdkConstructLibrary(
     def __init__(
         self,
         *,
+        edge_lambda_auto_discover: typing.Optional[builtins.bool] = None,
+        integration_test_auto_discover: typing.Optional[builtins.bool] = None,
         lambda_auto_discover: typing.Optional[builtins.bool] = None,
+        lambda_extension_auto_discover: typing.Optional[builtins.bool] = None,
         lambda_options: typing.Optional[typing.Union[projen.awscdk.LambdaFunctionCommonOptions, typing.Dict[str, typing.Any]]] = None,
         catalog: typing.Optional[typing.Union[projen.cdk.Catalog, typing.Dict[str, typing.Any]]] = None,
         cdk_version: builtins.str,
@@ -92,6 +95,8 @@ class AwsCdkConstructLibrary(
         repository_url: builtins.str,
         compat: typing.Optional[builtins.bool] = None,
         compat_ignore: typing.Optional[builtins.str] = None,
+        compress_assembly: typing.Optional[builtins.bool] = None,
+        docgen_file_path: typing.Optional[builtins.str] = None,
         dotnet: typing.Optional[typing.Union[projen.cdk.JsiiDotNetTarget, typing.Dict[str, typing.Any]]] = None,
         exclude_typescript: typing.Optional[typing.Sequence[builtins.str]] = None,
         publish_to_go: typing.Optional[typing.Union[projen.cdk.JsiiGoTarget, typing.Dict[str, typing.Any]]] = None,
@@ -118,9 +123,9 @@ class AwsCdkConstructLibrary(
         typescript_version: typing.Optional[builtins.str] = None,
         default_release_branch: builtins.str,
         artifacts_directory: typing.Optional[builtins.str] = None,
-        auto_approve_projen_upgrades: typing.Optional[builtins.bool] = None,
         auto_approve_upgrades: typing.Optional[builtins.bool] = None,
         build_workflow: typing.Optional[builtins.bool] = None,
+        build_workflow_triggers: typing.Optional[typing.Union[projen.github.workflows.Triggers, typing.Dict[str, typing.Any]]] = None,
         bundler_options: typing.Optional[typing.Union[projen.javascript.BundlerOptions, typing.Dict[str, typing.Any]]] = None,
         code_cov: typing.Optional[builtins.bool] = None,
         code_cov_token_secret: typing.Optional[builtins.str] = None,
@@ -142,19 +147,17 @@ class AwsCdkConstructLibrary(
         projen_dev_dependency: typing.Optional[builtins.bool] = None,
         projenrc_js: typing.Optional[builtins.bool] = None,
         projenrc_js_options: typing.Optional[typing.Union[projen.javascript.ProjenrcOptions, typing.Dict[str, typing.Any]]] = None,
-        projen_upgrade_auto_merge: typing.Optional[builtins.bool] = None,
-        projen_upgrade_schedule: typing.Optional[typing.Sequence[builtins.str]] = None,
-        projen_upgrade_secret: typing.Optional[builtins.str] = None,
         projen_version: typing.Optional[builtins.str] = None,
         pull_request_template: typing.Optional[builtins.bool] = None,
         pull_request_template_contents: typing.Optional[typing.Sequence[builtins.str]] = None,
         release: typing.Optional[builtins.bool] = None,
         release_to_npm: typing.Optional[builtins.bool] = None,
         release_workflow: typing.Optional[builtins.bool] = None,
-        workflow_bootstrap_steps: typing.Optional[typing.Sequence[typing.Any]] = None,
+        workflow_bootstrap_steps: typing.Optional[typing.Sequence[typing.Union[projen.github.workflows.JobStep, typing.Dict[str, typing.Any]]]] = None,
         workflow_git_identity: typing.Optional[typing.Union[projen.github.GitIdentity, typing.Dict[str, typing.Any]]] = None,
         workflow_node_version: typing.Optional[builtins.str] = None,
         auto_approve_options: typing.Optional[typing.Union[projen.github.AutoApproveOptions, typing.Dict[str, typing.Any]]] = None,
+        auto_merge: typing.Optional[builtins.bool] = None,
         auto_merge_options: typing.Optional[typing.Union[projen.github.AutoMergeOptions, typing.Dict[str, typing.Any]]] = None,
         clobber: typing.Optional[builtins.bool] = None,
         dev_container: typing.Optional[builtins.bool] = None,
@@ -164,6 +167,7 @@ class AwsCdkConstructLibrary(
         mergify: typing.Optional[builtins.bool] = None,
         mergify_options: typing.Optional[typing.Union[projen.github.MergifyOptions, typing.Dict[str, typing.Any]]] = None,
         project_type: typing.Optional[projen.ProjectType] = None,
+        projen_credentials: typing.Optional[projen.github.GithubCredentials] = None,
         projen_token_secret: typing.Optional[builtins.str] = None,
         readme: typing.Optional[typing.Union[projen.SampleReadmeProps, typing.Dict[str, typing.Any]]] = None,
         stale: typing.Optional[builtins.bool] = None,
@@ -200,10 +204,12 @@ class AwsCdkConstructLibrary(
         peer_deps: typing.Optional[typing.Sequence[builtins.str]] = None,
         repository: typing.Optional[builtins.str] = None,
         repository_directory: typing.Optional[builtins.str] = None,
+        scoped_packages_options: typing.Optional[typing.Sequence[typing.Union[projen.javascript.ScopedPackagesOptions, typing.Dict[str, typing.Any]]]] = None,
         scripts: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         stability: typing.Optional[builtins.str] = None,
         jsii_release_version: typing.Optional[builtins.str] = None,
         major_version: typing.Optional[jsii.Number] = None,
+        min_major_version: typing.Optional[jsii.Number] = None,
         npm_dist_tag: typing.Optional[builtins.str] = None,
         post_build_steps: typing.Optional[typing.Sequence[typing.Union[projen.github.workflows.JobStep, typing.Dict[str, typing.Any]]]] = None,
         prerelease: typing.Optional[builtins.str] = None,
@@ -222,15 +228,21 @@ class AwsCdkConstructLibrary(
         workflow_container_image: typing.Optional[builtins.str] = None,
         workflow_runs_on: typing.Optional[typing.Sequence[builtins.str]] = None,
         name: builtins.str,
+        commit_generated: typing.Optional[builtins.bool] = None,
         logging: typing.Optional[typing.Union[projen.LoggerOptions, typing.Dict[str, typing.Any]]] = None,
         outdir: typing.Optional[builtins.str] = None,
         parent: typing.Optional[projen.Project] = None,
         projen_command: typing.Optional[builtins.str] = None,
         projenrc_json: typing.Optional[builtins.bool] = None,
         projenrc_json_options: typing.Optional[typing.Union[projen.ProjenrcOptions, typing.Dict[str, typing.Any]]] = None,
+        renovatebot: typing.Optional[builtins.bool] = None,
+        renovatebot_options: typing.Optional[typing.Union[projen.RenovatebotOptions, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
+        :param edge_lambda_auto_discover: (experimental) Automatically adds an ``cloudfront.experimental.EdgeFunction`` for each ``.edge-lambda.ts`` handler in your source tree. If this is disabled, you can manually add an ``awscdk.AutoDiscover`` component to your project. Default: true
+        :param integration_test_auto_discover: (experimental) Automatically discovers and creates integration tests for each ``.integ.ts`` file in under your test directory. Default: true
         :param lambda_auto_discover: (experimental) Automatically adds an ``aws_lambda.Function`` for each ``.lambda.ts`` handler in your source tree. If this is disabled, you either need to explicitly call ``aws_lambda.Function.autoDiscover()`` or define a ``new aws_lambda.Function()`` for each handler. Default: true
+        :param lambda_extension_auto_discover: (experimental) Automatically adds an ``awscdk.LambdaExtension`` for each ``.lambda-extension.ts`` entrypoint in your source tree. If this is disabled, you can manually add an ``awscdk.AutoDiscover`` component to your project. Default: true
         :param lambda_options: (experimental) Common options for all AWS Lambda functions. Default: - default options
         :param catalog: (experimental) Libraries will be picked up by the construct catalog when they are published to npm as jsii modules and will be published under:. https://awscdk.io/packages/[@SCOPE/]PACKAGE@VERSION The catalog will also post a tweet to https://twitter.com/awscdkio with the package name, description and the above link. You can disable these tweets through ``{ announce: false }``. You can also add a Twitter handle through ``{ twitter: 'xx' }`` which will be mentioned in the tweet. Default: - new version will be announced
         :param cdk_version: (experimental) Minimum version of the AWS CDK to depend on. Default: "2.1.0"
@@ -246,6 +258,8 @@ class AwsCdkConstructLibrary(
         :param repository_url: (experimental) Git repository URL. Default: $GIT_REMOTE
         :param compat: (experimental) Automatically run API compatibility test against the latest version published to npm after compilation. - You can manually run compatibility tests using ``yarn compat`` if this feature is disabled. - You can ignore compatibility failures by adding lines to a ".compatignore" file. Default: false
         :param compat_ignore: (experimental) Name of the ignore file for API compatibility tests. Default: ".compatignore"
+        :param compress_assembly: (experimental) Emit a compressed version of the assembly. Default: false
+        :param docgen_file_path: (experimental) File path for generated docs. Default: "API.md"
         :param dotnet: 
         :param exclude_typescript: (experimental) Accepts a list of glob patterns. Files matching any of those patterns will be excluded from the TypeScript compiler input. By default, jsii will include all *.ts files (except .d.ts files) in the TypeScript compiler input. This can be problematic for example when the package's build or test procedure generates .ts files that cannot be compiled with jsii's compiler settings.
         :param publish_to_go: (experimental) Publish Go bindings to a git repository. Default: - no publishing
@@ -272,9 +286,9 @@ class AwsCdkConstructLibrary(
         :param typescript_version: (experimental) TypeScript version to use. NOTE: Typescript is not semantically versioned and should remain on the same minor, so we recommend using a ``~`` dependency (e.g. ``~1.2.3``). Default: "latest"
         :param default_release_branch: (experimental) The name of the main release branch. Default: "main"
         :param artifacts_directory: (experimental) A directory which will contain build artifacts. Default: "dist"
-        :param auto_approve_projen_upgrades: (experimental) Automatically approve projen upgrade PRs, allowing them to be merged by mergify (if configued). Throw if set to true but ``autoApproveOptions`` are not defined. Default: false
         :param auto_approve_upgrades: (experimental) Automatically approve deps upgrade PRs, allowing them to be merged by mergify (if configued). Throw if set to true but ``autoApproveOptions`` are not defined. Default: - true
         :param build_workflow: (experimental) Define a GitHub workflow for building PRs. Default: - true if not a subproject
+        :param build_workflow_triggers: (experimental) Build workflow triggers. Default: "{ pullRequest: {}, workflowDispatch: {} }"
         :param bundler_options: (experimental) Options for ``Bundler``.
         :param code_cov: (experimental) Define a GitHub workflow step for sending code coverage metrics to https://codecov.io/ Uses codecov/codecov-action@v1 A secret is required for private repos. Configured with @codeCovTokenSecret. Default: false
         :param code_cov_token_secret: (experimental) Define the secret name for a specified https://codecov.io/ token A secret is required to send coverage for private repositories. Default: - if this option is not specified, only public repositories are supported
@@ -283,7 +297,7 @@ class AwsCdkConstructLibrary(
         :param dependabot: (experimental) Use dependabot to handle dependency upgrades. Cannot be used in conjunction with ``depsUpgrade``. Default: false
         :param dependabot_options: (experimental) Options for dependabot. Default: - default options
         :param deps_upgrade: (experimental) Use github workflows to handle dependency upgrades. Cannot be used in conjunction with ``dependabot``. Default: true
-        :param deps_upgrade_options: (experimental) Options for depsUpgrade. Default: - default options
+        :param deps_upgrade_options: (experimental) Options for ``UpgradeDependencies``. Default: - default options
         :param gitignore: (experimental) Additional entries to .gitignore.
         :param jest: (experimental) Setup jest unit tests. Default: true
         :param jest_options: (experimental) Jest options. Default: - default options
@@ -296,9 +310,6 @@ class AwsCdkConstructLibrary(
         :param projen_dev_dependency: (experimental) Indicates of "projen" should be installed as a devDependency. Default: true
         :param projenrc_js: (experimental) Generate (once) .projenrc.js (in JavaScript). Set to ``false`` in order to disable .projenrc.js generation. Default: - true if projenrcJson is false
         :param projenrc_js_options: (experimental) Options for .projenrc.js. Default: - default options
-        :param projen_upgrade_auto_merge: (deprecated) Automatically approve projen upgrade PRs, allowing them to be merged by mergify (if configued). Throw if set to true but ``autoApproveOptions`` are not defined. Default: false
-        :param projen_upgrade_schedule: (experimental) Customize the projenUpgrade schedule in cron expression. Default: [ "0 6 * * *" ]
-        :param projen_upgrade_secret: (deprecated) Periodically submits a pull request for projen upgrades (executes ``yarn projen:upgrade``). This setting is a GitHub secret name which contains a GitHub Access Token with ``repo`` and ``workflow`` permissions. This token is used to submit the upgrade pull request, which will likely include workflow updates. To create a personal access token see https://github.com/settings/tokens Default: - no automatic projen upgrade pull requests
         :param projen_version: (experimental) Version of projen to install. Default: - Defaults to the latest version.
         :param pull_request_template: (experimental) Include a GitHub pull request template. Default: true
         :param pull_request_template_contents: (experimental) The contents of the pull request template. Default: - default content
@@ -309,7 +320,8 @@ class AwsCdkConstructLibrary(
         :param workflow_git_identity: (experimental) The git identity to use in workflows. Default: - GitHub Actions
         :param workflow_node_version: (experimental) The node version to use in GitHub workflows. Default: - same as ``minNodeVersion``
         :param auto_approve_options: (experimental) Enable and configure the 'auto approve' workflow. Default: - auto approve is disabled
-        :param auto_merge_options: (experimental) Configure options for automatic merging on GitHub. Has no effect if ``github.mergify`` is set to false. Default: - see defaults in ``AutoMergeOptions``
+        :param auto_merge: (experimental) Enable automatic merging on GitHub. Has no effect if ``github.mergify`` is set to false. Default: true
+        :param auto_merge_options: (experimental) Configure options for automatic merging on GitHub. Has no effect if ``github.mergify`` or ``autoMerge`` is set to false. Default: - see defaults in ``AutoMergeOptions``
         :param clobber: (experimental) Add a ``clobber`` task which resets the repo to origin. Default: true
         :param dev_container: (experimental) Add a VSCode development environment (used for GitHub Codespaces). Default: false
         :param github: (experimental) Enable GitHub integration. Enabled by default for root projects. Disabled for non-root projects. Default: true
@@ -318,9 +330,10 @@ class AwsCdkConstructLibrary(
         :param mergify: (deprecated) Whether mergify should be enabled on this repository or not. Default: true
         :param mergify_options: (deprecated) Options for mergify. Default: - default options
         :param project_type: (deprecated) Which type of project this is (library/app). Default: ProjectType.UNKNOWN
-        :param projen_token_secret: (experimental) The name of a secret which includes a GitHub Personal Access Token to be used by projen workflows. This token needs to have the ``repo``, ``workflows`` and ``packages`` scope. Default: "PROJEN_GITHUB_TOKEN"
+        :param projen_credentials: (experimental) Choose a method of providing GitHub API access for projen workflows. Default: - use a personal access token named PROJEN_GITHUB_TOKEN
+        :param projen_token_secret: (deprecated) The name of a secret which includes a GitHub Personal Access Token to be used by projen workflows. This token needs to have the ``repo``, ``workflows`` and ``packages`` scope. Default: "PROJEN_GITHUB_TOKEN"
         :param readme: (experimental) The README setup. Default: - { filename: 'README.md', contents: '# replace this' }
-        :param stale: (experimental) Auto-close of stale issues and pull request. See ``staleOptions`` for options. Default: true
+        :param stale: (experimental) Auto-close of stale issues and pull request. See ``staleOptions`` for options. Default: false
         :param stale_options: (experimental) Auto-close stale issues and pull requests. To disable set ``stale`` to ``false``. Default: - see defaults in ``StaleOptions``
         :param vscode: (experimental) Enable VSCode integration. Enabled by default for root projects. Disabled for non-root projects. Default: true
         :param allow_library_dependencies: (experimental) Allow the project to include ``peerDependencies`` and ``bundledDependencies``. This is normally only allowed for libraries. For apps, there's no meaning for specifying these. Default: true
@@ -333,7 +346,7 @@ class AwsCdkConstructLibrary(
         :param bugs_email: (experimental) The email address to which issues should be reported.
         :param bugs_url: (experimental) The url to your project's issue tracker.
         :param bundled_deps: (experimental) List of dependencies to bundle into this module. These modules will be added both to the ``dependencies`` section and ``bundledDependencies`` section of your ``package.json``. The recommendation is to only specify the module name here (e.g. ``express``). This will behave similar to ``yarn add`` or ``npm install`` in the sense that it will add the module as a dependency to your ``package.json`` file with the latest version (``^``). You can specify semver requirements in the same syntax passed to ``npm i`` or ``yarn add`` (e.g. ``express@^2``) and this will be what you ``package.json`` will eventually include.
-        :param code_artifact_options: (experimental) Options for publishing npm package to AWS CodeArtifact. Default: - undefined
+        :param code_artifact_options: (experimental) Options for npm packages using AWS CodeArtifact. This is required if publishing packages to, or installing scoped packages from AWS CodeArtifact Default: - undefined
         :param deps: (experimental) Runtime dependencies of this module. The recommendation is to only specify the module name here (e.g. ``express``). This will behave similar to ``yarn add`` or ``npm install`` in the sense that it will add the module as a dependency to your ``package.json`` file with the latest version (``^``). You can specify semver requirements in the same syntax passed to ``npm i`` or ``yarn add`` (e.g. ``express@^2``) and this will be what you ``package.json`` will eventually include. Default: []
         :param description: (experimental) The description is just a string that helps people understand the purpose of the package. It can be used when searching for packages in a package manager as well. See https://classic.yarnpkg.com/en/docs/package-json/#toc-description
         :param dev_deps: (experimental) Build dependencies for this module. These dependencies will only be available in your build environment but will not be fetched when this module is consumed. The recommendation is to only specify the module name here (e.g. ``express``). This will behave similar to ``yarn add`` or ``npm install`` in the sense that it will add the module as a dependency to your ``package.json`` file with the latest version (``^``). You can specify semver requirements in the same syntax passed to ``npm i`` or ``yarn add`` (e.g. ``express@^2``) and this will be what you ``package.json`` will eventually include. Default: []
@@ -354,10 +367,12 @@ class AwsCdkConstructLibrary(
         :param peer_deps: (experimental) Peer dependencies for this module. Dependencies listed here are required to be installed (and satisfied) by the *consumer* of this library. Using peer dependencies allows you to ensure that only a single module of a certain library exists in the ``node_modules`` tree of your consumers. Note that prior to npm@7, peer dependencies are *not* automatically installed, which means that adding peer dependencies to a library will be a breaking change for your customers. Unless ``peerDependencyOptions.pinnedDevDependency`` is disabled (it is enabled by default), projen will automatically add a dev dependency with a pinned version for each peer dependency. This will ensure that you build & test your module against the lowest peer version required. Default: []
         :param repository: (experimental) The repository is the location where the actual code for your package lives. See https://classic.yarnpkg.com/en/docs/package-json/#toc-repository
         :param repository_directory: (experimental) If the package.json for your package is not in the root directory (for example if it is part of a monorepo), you can specify the directory in which it lives.
+        :param scoped_packages_options: (experimental) Options for privately hosted scoped packages. Default: - fetch all scoped packages from the public npm registry
         :param scripts: (experimental) npm scripts to include. If a script has the same name as a standard script, the standard script will be overwritten. Default: {}
         :param stability: (experimental) Package's Stability.
-        :param jsii_release_version: (experimental) Version requirement of ``jsii-release`` which is used to publish modules to npm. Default: "latest"
+        :param jsii_release_version: (experimental) Version requirement of ``publib`` which is used to publish modules to npm. Default: "latest"
         :param major_version: (experimental) Major version to release from the default branch. If this is specified, we bump the latest version of this major version line. If not specified, we bump the global latest version. Default: - Major version is not enforced.
+        :param min_major_version: (experimental) Minimal Major version to release. This can be useful to set to 1, as breaking changes before the 1.x major release are not incrementing the major version number. Can not be set together with ``majorVersion``. Default: - No minimum version is being enforced
         :param npm_dist_tag: (experimental) The npmDistTag to use when publishing from the default branch. To set the npm dist-tag for release branches, set the ``npmDistTag`` property for each branch. Default: "latest"
         :param post_build_steps: (experimental) Steps to execute after build as part of the release workflow. Default: []
         :param prerelease: (experimental) Bump versions from the default branch as pre-releases (e.g. "beta", "alpha", "pre"). Default: - normal semantic versions
@@ -376,17 +391,23 @@ class AwsCdkConstructLibrary(
         :param workflow_container_image: (experimental) Container image to use for GitHub workflows. Default: - default image
         :param workflow_runs_on: (experimental) Github Runner selection labels. Default: ["ubuntu-latest"]
         :param name: (experimental) This is the name of your project. Default: $BASEDIR
+        :param commit_generated: (experimental) Whether to commit the managed files by default. Default: true
         :param logging: (experimental) Configure logging options such as verbosity. Default: {}
         :param outdir: (experimental) The root directory of the project. Relative to this directory, all files are synthesized. If this project has a parent, this directory is relative to the parent directory and it cannot be the same as the parent or any of it's other sub-projects. Default: "."
         :param parent: (experimental) The parent project, if this project is part of a bigger project.
         :param projen_command: (experimental) The shell command to use in order to run the projen CLI. Can be used to customize in special environments. Default: "npx projen"
         :param projenrc_json: (experimental) Generate (once) .projenrc.json (in JSON). Set to ``false`` in order to disable .projenrc.json generation. Default: false
         :param projenrc_json_options: (experimental) Options for .projenrc.json. Default: - default options
+        :param renovatebot: (experimental) Use renovatebot to handle dependency upgrades. Default: false
+        :param renovatebot_options: (experimental) Options for renovatebot. Default: - default options
 
         :stability: experimental
         '''
         options = projen.awscdk.AwsCdkConstructLibraryOptions(
+            edge_lambda_auto_discover=edge_lambda_auto_discover,
+            integration_test_auto_discover=integration_test_auto_discover,
             lambda_auto_discover=lambda_auto_discover,
+            lambda_extension_auto_discover=lambda_extension_auto_discover,
             lambda_options=lambda_options,
             catalog=catalog,
             cdk_version=cdk_version,
@@ -402,6 +423,8 @@ class AwsCdkConstructLibrary(
             repository_url=repository_url,
             compat=compat,
             compat_ignore=compat_ignore,
+            compress_assembly=compress_assembly,
+            docgen_file_path=docgen_file_path,
             dotnet=dotnet,
             exclude_typescript=exclude_typescript,
             publish_to_go=publish_to_go,
@@ -428,9 +451,9 @@ class AwsCdkConstructLibrary(
             typescript_version=typescript_version,
             default_release_branch=default_release_branch,
             artifacts_directory=artifacts_directory,
-            auto_approve_projen_upgrades=auto_approve_projen_upgrades,
             auto_approve_upgrades=auto_approve_upgrades,
             build_workflow=build_workflow,
+            build_workflow_triggers=build_workflow_triggers,
             bundler_options=bundler_options,
             code_cov=code_cov,
             code_cov_token_secret=code_cov_token_secret,
@@ -452,9 +475,6 @@ class AwsCdkConstructLibrary(
             projen_dev_dependency=projen_dev_dependency,
             projenrc_js=projenrc_js,
             projenrc_js_options=projenrc_js_options,
-            projen_upgrade_auto_merge=projen_upgrade_auto_merge,
-            projen_upgrade_schedule=projen_upgrade_schedule,
-            projen_upgrade_secret=projen_upgrade_secret,
             projen_version=projen_version,
             pull_request_template=pull_request_template,
             pull_request_template_contents=pull_request_template_contents,
@@ -465,6 +485,7 @@ class AwsCdkConstructLibrary(
             workflow_git_identity=workflow_git_identity,
             workflow_node_version=workflow_node_version,
             auto_approve_options=auto_approve_options,
+            auto_merge=auto_merge,
             auto_merge_options=auto_merge_options,
             clobber=clobber,
             dev_container=dev_container,
@@ -474,6 +495,7 @@ class AwsCdkConstructLibrary(
             mergify=mergify,
             mergify_options=mergify_options,
             project_type=project_type,
+            projen_credentials=projen_credentials,
             projen_token_secret=projen_token_secret,
             readme=readme,
             stale=stale,
@@ -510,10 +532,12 @@ class AwsCdkConstructLibrary(
             peer_deps=peer_deps,
             repository=repository,
             repository_directory=repository_directory,
+            scoped_packages_options=scoped_packages_options,
             scripts=scripts,
             stability=stability,
             jsii_release_version=jsii_release_version,
             major_version=major_version,
+            min_major_version=min_major_version,
             npm_dist_tag=npm_dist_tag,
             post_build_steps=post_build_steps,
             prerelease=prerelease,
@@ -532,12 +556,15 @@ class AwsCdkConstructLibrary(
             workflow_container_image=workflow_container_image,
             workflow_runs_on=workflow_runs_on,
             name=name,
+            commit_generated=commit_generated,
             logging=logging,
             outdir=outdir,
             parent=parent,
             projen_command=projen_command,
             projenrc_json=projenrc_json,
             projenrc_json_options=projenrc_json_options,
+            renovatebot=renovatebot,
+            renovatebot_options=renovatebot_options,
         )
 
         jsii.create(self.__class__, self, [options])
